# ===== THIS FILE IS GENERATED FROM A TEMPLATE ===== #
# ============== DO NOT EDIT DIRECTLY ============== #

from .motion_lib_exception import MotionLibException


class DeviceFailedException(MotionLibException):
    """
    Thrown when a device registers fatal failure.
    Contact support if you observe this exception.
    """
